@@ -7,8 +7,7 @@ import (
 
 	"github.com/elves/elvish/daemon"
 	"github.com/elves/elvish/eval"
-	"github.com/elves/elvish/eval/types"
-	"github.com/elves/elvish/eval/vartypes"
+	"github.com/elves/elvish/eval/vars"
 	daemonp "github.com/elves/elvish/program/daemon"
 	"github.com/elves/elvish/util"
 )
@@ -20,29 +19,23 @@ var errDontKnowHowToSpawnDaemon = errors.New("don't know how to spawn daemon")
 // Ns makes the daemon: namespace.
 func Ns(daemon *daemon.Client, spawner *daemonp.Daemon) eval.Ns {
 	// Obtain process ID
-	daemonPid := func() types.Value {
+	getPid := func() interface{} {
 		pid, err := daemon.Pid()
 		if err != nil {
 			util.Throw(err)
 		}
-		return types.String(strconv.Itoa(pid))
+		return string(strconv.Itoa(pid))
 	}
 
-	daemonSpawn := func(ec *eval.Frame, args []types.Value, opts map[string]types.Value) {
-		eval.TakeNoArg(args)
-		eval.TakeNoOpt(opts)
+	spawn := func() error {
 		if spawner == nil {
-			util.Throw(errDontKnowHowToSpawnDaemon)
-		}
-		err := spawner.Spawn()
-		if err != nil {
-			util.Throw(err)
+			return errDontKnowHowToSpawnDaemon
 		}
+		return spawner.Spawn()
 	}
-	return eval.Ns{
-		"pid":  vartypes.NewRoCallback(daemonPid),
-		"sock": vartypes.NewRo(types.String(daemon.SockPath())),
 
-		"spawn" + eval.FnSuffix: vartypes.NewRo(&eval.BuiltinFn{"daemon:spawn", daemonSpawn}),
-	}
+	return eval.Ns{
+		"pid":  vars.FromGet(getPid),
+		"sock": vars.NewRo(string(daemon.SockPath())),
+	}.AddBuiltinFn("daemon:", "spawn", spawn)
 }
