@@ -49,7 +49,7 @@ func script(ev *eval.Evaler, args []string, cmd, compileOnly bool) error {
 		return nil
 	}
 
-	return ev.Eval(op, src)
+	return ev.EvalWithStdPorts(op, src)
 }
 
 var errSourceNotUTF8 = errors.New("source is not UTF-8")
