@@ -3,8 +3,9 @@ package program
 import (
 	"fmt"
 	"os"
+	"runtime"
 
-	"github.com/elves/elvish/build"
+	"github.com/elves/elvish/buildinfo"
 	daemonsvc "github.com/elves/elvish/daemon"
 	"github.com/elves/elvish/program/daemon"
 )
@@ -33,8 +34,7 @@ func (s ShowCorrectUsage) Main([]string) int {
 type ShowVersion struct{}
 
 func (ShowVersion) Main([]string) int {
-	fmt.Println(build.Version)
-	fmt.Fprintln(os.Stderr, "-version is deprecated and will be removed in 0.12. Use -buildinfo instead.")
+	fmt.Println(buildinfo.Version)
 	return 0
 }
 
@@ -45,11 +45,16 @@ type ShowBuildInfo struct {
 
 func (info ShowBuildInfo) Main([]string) int {
 	if info.JSON {
-		fmt.Printf("{version: %s, builder: %s}\n",
-			quoteJSON(build.Version), quoteJSON(build.Builder))
+		fmt.Printf(`{"version": %s,`, quoteJSON(buildinfo.Version))
+		fmt.Printf(` "goversion": %s,`, quoteJSON(runtime.Version()))
+		fmt.Printf(` "goroot": %s,`, quoteJSON(buildinfo.GoRoot))
+		fmt.Printf(` "gopath": %s}`, quoteJSON(buildinfo.GoPath))
+		fmt.Println()
 	} else {
-		fmt.Println("version:", build.Version)
-		fmt.Println("builder:", build.Builder)
+		fmt.Println("Version:", buildinfo.Version)
+		fmt.Println("Go version:", runtime.Version())
+		fmt.Println("GOROOT at build time:", buildinfo.GoRoot)
+		fmt.Println("GOPATH at build time:", buildinfo.GoPath)
 	}
 	return 0
 }
