@@ -13,6 +13,9 @@ var (
 	wantedDirs = []storedefs.Dir{
 		{"/usr", scoreIncrement*scoreDecay*scoreDecay + scoreIncrement},
 		{"/usr/bin", scoreIncrement * scoreDecay}}
+	dirToDel           = "/usr"
+	wantedDirsAfterDel = []storedefs.Dir{
+		{"/usr/bin", scoreIncrement * scoreDecay}}
 )
 
 func TestDir(t *testing.T) {
@@ -28,4 +31,11 @@ func TestDir(t *testing.T) {
 		t.Errorf(`tStore.ListDirs() => (%v, %v), want (%v, <nil>)`,
 			dirs, err, wantedDirs)
 	}
+
+	tStore.DelDir("/usr")
+	dirs, err = tStore.Dirs(black)
+	if err != nil || !reflect.DeepEqual(dirs, wantedDirsAfterDel) {
+		t.Errorf(`After DelDir("/usr"), tStore.ListDirs() => (%v, %v), want (%v, <nil>)`,
+			dirs, err, wantedDirsAfterDel)
+	}
 }
